RoomToolkit class

Inheritance

Constructors

RoomToolkit({required String name, String? title, String? description, String? thumbnailUrl, required List<BaseTool> tools})

Properties

description String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
rules List<String>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl String?
finalinherited
title String?
finalinherited
tools List<BaseTool>
finalinherited

Methods

execute(ToolContext context, String name, ToolInput input) Future<ToolCallOutput>
inherited
getTool(String name) → BaseTool
inherited
getTools() Map<String, dynamic>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited