RoomContentTool class
- Inheritance
-
- Object
- BaseTool
- ContentTool
- RoomContentTool
Constructors
-
RoomContentTool({required String toolkitName, required String name, required Map<
String, dynamic> inputSchema, ToolContentSpec? inputSpec, ToolContentSpec? outputSpec, Map<String, dynamic> ? outputSchema, Map<String, dynamic> ? defs, String? pricing, bool supportsContext = false, required String? title, required String? description, String? thumbnailUrl, String? participantId, String? onBehalfOfId})
Properties
-
defs
→ Map<
String, dynamic> ? -
finalinherited
- description → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputSchema
→ Map<
String, dynamic> -
finalinherited
- inputSpec → ToolContentSpec?
-
finalinherited
- name → String
-
finalinherited
- onBehalfOfId → String?
-
final
-
outputSchema
→ Map<
String, dynamic> ? -
finalinherited
- outputSpec → ToolContentSpec?
-
finalinherited
- participantId → String?
-
final
- pricing → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsContext → bool
-
finalinherited
- thumbnailUrl → String?
-
finalinherited
- title → String?
-
finalinherited
- toolkitName → String
-
final
Methods
-
execute(
ToolContext context, ToolInput input) → Future< ToolCallOutput> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited